@@ -6,8 +6,8 @@ function(x,
                        points = 512) {
 ## The all-in-one include header for the HyRiM R package
 #
-# Authors:         Sandra König, sandra.koenig@ait.ac.at 
-#                  Stefan Rass, stefan.rass@aau.at  
+# Authors:         Sandra König, sandra.koenig@ait.ac.at
+#                  Stefan Rass, stefan.rass@aau.at
 #
 # Copyright (C) 2014-2020 AIT Austrian Institute of Technology
 # AIT Austrian Institute of Technology GmbH
@@ -15,10 +15,10 @@ function(x,
 # http://www.ait.ac.at
 #
 # This file is part of the AIT HyRiM R Package.
-# The AIT HyRiM R Package can be used for non-commercial and 
-# academic as well as evaluation purposes. For further information on 
+# The AIT HyRiM R Package can be used for non-commercial and
+# academic as well as evaluation purposes. For further information on
 # commercial use, please contact the authors!
-# 
+#
 # The AIT HyRiM R Package is free software: you can redistribute
 # it and/or modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation, either version 3 of
@@ -35,7 +35,8 @@ function(x,
 #
    fcall <- match.call(expand.dots = FALSE)
   # trivial case: compare two degenerate distributions
-  if (class(x) == "numeric" && class(y) == "numeric") {
+  #if (class(x) == "numeric" && class(y) == "numeric") {
+  if (is(x, "numeric") && is(y, "numeric")) {
     if (verbose) { return(min(x,y)) }
     else {
       if (x < y) { return(1) }
@@ -43,12 +44,14 @@ function(x,
       return(0) # upon identity
     }
   }
-  
+
   # simple case: compare a distribution to a number
-  if ((class(x) == "mosg.lossdistribution" && class(y) == "numeric") ||
-      (class(x) == "numeric" && class(y) == "mosg.lossdistribution")) {
-    
-    if (class(x) == "numeric" && class(y) == "mosg.lossdistribution") {
+  #if ((class(x) == "mosg.lossdistribution" && class(y) == "numeric") ||
+  #    (class(x) == "numeric" && class(y) == "mosg.lossdistribution")) {
+  if ((is(x, "mosg.lossdistribution") && is(y, "numeric")) ||
+        (is(x, "numeric") && is(y, "mosg.lossdistribution"))) {
+    #if (class(x) == "numeric" && class(y) == "mosg.lossdistribution") {
+    if (is(x, "numeric") && is(y, "mosg.lossdistribution")) {
       # switch x and y accordingly so that x is the distribution and y is the number
       z <- x
       x <- y
@@ -84,12 +87,13 @@ function(x,
       return(ifelse(bSwitch, 1, 2)) # return argument index only (reversing the argument switch if it happened)
     }
   }
-  
-  # to handle multiple goals, including the case of two distributions only, 
+
+  # to handle multiple goals, including the case of two distributions only,
   # we create a list and flatten it. In case that x and y are loss distributions,
   # the resulting list will be singleton. In case of x and y being lists, the resulting
   # list will be a plain list again. So, in any case, we can iterate over the elements easily
-  if (class(x) == "mosg.lossdistribution" && class(y) == "mosg.lossdistribution") {
+  #if (class(x) == "mosg.lossdistribution" && class(y) == "mosg.lossdistribution") {
+  if (is(x, "mosg.lossdistribution") && is(y, "mosg.lossdistribution")) {
     xList <- list(x)
     yList <- list(y)
   }
@@ -97,7 +101,7 @@ function(x,
     xList <- x
     yList <- y
   }
-  
+
   n <- length(xList)
   if (n != length(yList)) {
     stop("number of criteria differs between 'x' and 'y'")
@@ -117,8 +121,10 @@ function(x,
     xi <- xList[[i]]
     yi <- yList[[i]]
     # nontrivial case: compare distributions to one another
-    if (class(xi) != "mosg.lossdistribution" ||
-        class(yi) != "mosg.lossdistribution") {
+    #if (class(xi) != "mosg.lossdistribution" ||
+    #    class(yi) != "mosg.lossdistribution") {
+    if (!is(xi, "mosg.lossdistribution") ||
+        !is(yi, "mosg.lossdistribution")) {
       stop("preferences can only be computed between loss distributions")
     }
     if (xi$is.discrete != yi$is.discrete) {
@@ -145,7 +151,7 @@ function(x,
       delta <- delta + weights[[i]] * (density(xi, h) - density(yi, h))
     }
   }
-  
+
   if (all(delta == 0)) {
     if (verbose) {
       #cat("\ndistributions are identical\n")
@@ -153,7 +159,7 @@ function(x,
     }
     return(0)  # distributions are identical
   }
-  
+
   lastNonzero <- max(which(delta != 0))
   if (delta[lastNonzero] < 0) {
     if (verbose) {
